@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -26,10 +26,10 @@
 #include <QString>
 #include <QMap>
 
+namespace KContacts {
 /** @short Class that holds a ClientPidMap for a contact.
  *  @since 5.4
  */
-namespace KContacts {
 class KCONTACTS_EXPORT ClientPidMap
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const ClientPidMap &);
@@ -44,19 +44,19 @@ public:
     typedef QVector<ClientPidMap> List;
 
     void setClientPidMap(const QString &clientpidmap);
-    QString clientPidMap() const;
+    Q_REQUIRED_RESULT QString clientPidMap() const;
 
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
 
     void setParameters(const QMap<QString, QStringList> &params);
-    QMap<QString, QStringList> parameters() const;
+    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
 
-    bool operator==(const ClientPidMap &other) const;
-    bool operator!=(const ClientPidMap &other) const;
+    Q_REQUIRED_RESULT bool operator==(const ClientPidMap &other) const;
+    Q_REQUIRED_RESULT bool operator!=(const ClientPidMap &other) const;
 
     ClientPidMap &operator=(const ClientPidMap &other);
 
-    QString toString() const;
+    Q_REQUIRED_RESULT QString toString() const;
 private:
     class Private;
     QSharedDataPointer<Private> d;
